@@ -68,6 +68,7 @@ class vmmDeleteDialog(vmmGObjectUI):
 
 
     def show(self, vm, parent):
+        logging.debug("Showing delete wizard")
         self.vm = vm
         self.conn = vm.conn
 
@@ -76,6 +77,7 @@ class vmmDeleteDialog(vmmGObjectUI):
         self.topwin.present()
 
     def close(self, ignore1=None, ignore2=None):
+        logging.debug("Closing delete wizard")
         self.topwin.hide()
         self.vm = None
         self.conn = None
@@ -91,7 +93,7 @@ class vmmDeleteDialog(vmmGObjectUI):
 
         # Set VM name in title'
         title_str = ("<span size='x-large'>%s '%s'</span>" %
-                     (_("Delete"), self.vm.get_name()))
+                     (_("Delete"), util.xml_escape(self.vm.get_name())))
         self.widget("delete-main-label").set_markup(title_str)
 
         self.widget("delete-cancel").grab_focus()
@@ -162,7 +164,7 @@ class vmmDeleteDialog(vmmGObjectUI):
 
             for path in paths:
                 try:
-                    logging.debug("Deleting path: %s" % path)
+                    logging.debug("Deleting path: %s", path)
                     meter.start(text=_("Deleting path '%s'") % path)
                     self._async_delete_path(newconn, path, meter)
                 except Exception, e:
@@ -170,7 +172,7 @@ class vmmDeleteDialog(vmmGObjectUI):
                                           "".join(traceback.format_exc())))
                 meter.end(0)
 
-            logging.debug("Removing VM '%s'" % self.vm.get_name())
+            logging.debug("Removing VM '%s'", self.vm.get_name())
             self.vm.delete()
 
         except Exception, e:
@@ -183,7 +185,7 @@ class vmmDeleteDialog(vmmGObjectUI):
         for errinfo in storage_errors:
             storage_errstr += "%s\n%s\n" % (errinfo[0], errinfo[1])
 
-        if not storage_errstr:
+        if not storage_errstr and not details:
             return
 
         # We had extra storage errors. If there was another error message,
@@ -207,7 +209,7 @@ class vmmDeleteDialog(vmmGObjectUI):
         try:
             vol = conn.storageVolLookupByPath(path)
         except:
-            logging.debug("Path '%s' is not managed. Deleting locally." % path)
+            logging.debug("Path '%s' is not managed. Deleting locally", path)
 
         if vol:
             vol.delete(0)
@@ -371,7 +373,7 @@ def do_we_default(conn, vm_name, vol, path, ro, shared):
             info = append_str(info, _("Storage is in use by the following "
                                       "virtual machines:\n- %s " % namestr))
     except Exception, e:
-        logging.exception("Failed checking disk conflict: %s" % str(e))
+        logging.exception("Failed checking disk conflict: %s", str(e))
 
     return (not info, info)
 
