@@ -286,6 +286,7 @@ class vmmHost(vmmGObjectUI):
 
 
     def show(self):
+        logging.debug("Showing host details: %s", self.conn)
         vis = self.is_visible()
         self.topwin.present()
         if vis:
@@ -297,6 +298,7 @@ class vmmHost(vmmGObjectUI):
         return bool(self.topwin.flags() & gtk.VISIBLE)
 
     def close(self, ignore1=None, ignore2=None):
+        logging.debug("Closing host details: %s", self.conn)
         if not self.is_visible():
             return
 
@@ -417,7 +419,7 @@ class vmmHost(vmmGObjectUI):
         if not result:
             return
 
-        logging.debug("Deleting network '%s'" % net.get_name())
+        logging.debug("Deleting network '%s'", net.get_name())
         vmmAsyncJob.simple_async_noshow(net.delete, [], self,
                             _("Error deleting network '%s'") % net.get_name())
 
@@ -426,7 +428,7 @@ class vmmHost(vmmGObjectUI):
         if net is None:
             return
 
-        logging.debug("Starting network '%s'" % net.get_name())
+        logging.debug("Starting network '%s'", net.get_name())
         vmmAsyncJob.simple_async_noshow(net.start, [], self,
                             _("Error starting network '%s'") % net.get_name())
 
@@ -435,7 +437,7 @@ class vmmHost(vmmGObjectUI):
         if net is None:
             return
 
-        logging.debug("Stopping network '%s'" % net.get_name())
+        logging.debug("Stopping network '%s'", net.get_name())
         vmmAsyncJob.simple_async_noshow(net.stop, [], self,
                             _("Error stopping network '%s'") % net.get_name())
 
@@ -453,7 +455,7 @@ class vmmHost(vmmGObjectUI):
         if net is None:
             return
 
-        logging.debug("Applying changes for network '%s'" % net.get_name())
+        logging.debug("Applying changes for network '%s'", net.get_name())
         try:
             auto = self.widget("net-autostart").get_active()
             net.set_autostart(auto)
@@ -609,7 +611,7 @@ class vmmHost(vmmGObjectUI):
         if pool is None:
             return
 
-        logging.debug("Stopping pool '%s'" % pool.get_name())
+        logging.debug("Stopping pool '%s'", pool.get_name())
         vmmAsyncJob.simple_async_noshow(pool.stop, [], self,
                             _("Error stopping pool '%s'") % pool.get_name())
 
@@ -618,7 +620,7 @@ class vmmHost(vmmGObjectUI):
         if pool is None:
             return
 
-        logging.debug("Starting pool '%s'" % pool.get_name())
+        logging.debug("Starting pool '%s'", pool.get_name())
         vmmAsyncJob.simple_async_noshow(pool.start, [], self,
                             _("Error starting pool '%s'") % pool.get_name())
 
@@ -632,7 +634,7 @@ class vmmHost(vmmGObjectUI):
         if not result:
             return
 
-        logging.debug("Deleting pool '%s'" % pool.get_name())
+        logging.debug("Deleting pool '%s'", pool.get_name())
         vmmAsyncJob.simple_async_noshow(pool.delete, [], self,
                             _("Error deleting pool '%s'") % pool.get_name())
 
@@ -645,7 +647,7 @@ class vmmHost(vmmGObjectUI):
             pool.refresh()
             self.refresh_current_pool()
 
-        logging.debug("Refresh pool '%s'" % pool.get_name())
+        logging.debug("Refresh pool '%s'", pool.get_name())
         vmmAsyncJob.simple_async_noshow(cb, [], self,
                             _("Error refreshing pool '%s'") % pool.get_name())
 
@@ -664,7 +666,7 @@ class vmmHost(vmmGObjectUI):
             self.refresh_current_pool()
             self.populate_storage_volumes()
 
-        logging.debug("Deleting volume '%s'" % vol.get_name())
+        logging.debug("Deleting volume '%s'", vol.get_name())
         vmmAsyncJob.simple_async_noshow(cb, [], self,
                         _("Error refreshing volume '%s'") % vol.get_name())
 
@@ -682,7 +684,7 @@ class vmmHost(vmmGObjectUI):
         if pool is None:
             return
 
-        logging.debug("Launching 'Add Volume' wizard for pool '%s'" %
+        logging.debug("Launching 'Add Volume' wizard for pool '%s'",
                       pool.get_name())
         try:
             if self.addvol is None:
@@ -725,7 +727,7 @@ class vmmHost(vmmGObjectUI):
         if pool is None:
             return
 
-        logging.debug("Applying changes for pool '%s'" % pool.get_name())
+        logging.debug("Applying changes for pool '%s'", pool.get_name())
         try:
             do_auto = self.widget("pool-autostart").get_active()
             pool.set_autostart(do_auto)
@@ -874,7 +876,16 @@ class vmmHost(vmmGObjectUI):
         for key in vols.keys():
             vol = vols[key]
 
-            path = vol.get_target_path()
+            try:
+                path = vol.get_target_path()
+                name = vol.get_name()
+                cap = vol.get_pretty_capacity()
+                fmt = vol.get_format() or ""
+            except:
+                logging.debug("Error getting volume info for '%s', "
+                              "hiding it", key, exc_info=True)
+                continue
+
             namestr = None
             try:
                 if path:
@@ -885,8 +896,8 @@ class vmmHost(vmmGObjectUI):
             except:
                 logging.exception("Failed to determine if storage volume in "
                                   "use.")
-            model.append([key, vol.get_name(), vol.get_pretty_capacity(),
-                          vol.get_format() or "", namestr])
+
+            model.append([key, name, cap, fmt, namestr])
 
 
     #############################
@@ -904,7 +915,7 @@ class vmmHost(vmmGObjectUI):
                     "'%s'?" % interface.get_name())):
             return
 
-        logging.debug("Stopping interface '%s'" % interface.get_name())
+        logging.debug("Stopping interface '%s'", interface.get_name())
         vmmAsyncJob.simple_async_noshow(interface.stop, [], self,
                     _("Error stopping interface '%s'") % interface.get_name())
 
@@ -919,7 +930,7 @@ class vmmHost(vmmGObjectUI):
                     "'%s'?" % interface.get_name())):
             return
 
-        logging.debug("Starting interface '%s'" % interface.get_name())
+        logging.debug("Starting interface '%s'", interface.get_name())
         vmmAsyncJob.simple_async_noshow(interface.start, [], self,
                     _("Error starting interface '%s'") % interface.get_name())
 
@@ -934,7 +945,7 @@ class vmmHost(vmmGObjectUI):
         if not result:
             return
 
-        logging.debug("Deleting interface '%s'" % interface.get_name())
+        logging.debug("Deleting interface '%s'", interface.get_name())
         vmmAsyncJob.simple_async_noshow(interface.delete, [], self,
                     _("Error deleting interface '%s'") % interface.get_name())
 
@@ -973,7 +984,7 @@ class vmmHost(vmmGObjectUI):
         model = start_list.get_model()
         newmode = model[start_list.get_active()][0]
 
-        logging.debug("Applying changes for interface '%s'" %
+        logging.debug("Applying changes for interface '%s'",
                       interface.get_name())
         try:
             interface.set_startmode(newmode)
