@@ -18,8 +18,7 @@
 # MA 02110-1301 USA.
 #
 
-import virtinst.util as util
-
+from virtManager import util
 from virtManager.IPy import IP
 from virtManager.libvirtobject import vmmLibvirtObject
 
@@ -47,8 +46,8 @@ class vmmNetwork(vmmLibvirtObject):
 
         return desc
 
-    def __init__(self, connection, net, uuid, active):
-        vmmLibvirtObject.__init__(self, connection)
+    def __init__(self, conn, net, uuid, active):
+        vmmLibvirtObject.__init__(self, conn)
         self.net = net
         self.uuid = uuid
         self.active = active
@@ -59,11 +58,7 @@ class vmmNetwork(vmmLibvirtObject):
     def _XMLDesc(self, flags):
         return self.net.XMLDesc(flags)
     def _define(self, xml):
-        return self.get_connection().vmm.networkDefineXML(xml)
-
-
-    def set_handle(self, net):
-        self.net = net
+        return self.conn.vmm.networkDefineXML(xml)
 
     def set_active(self, state):
         self.active = state
@@ -102,8 +97,8 @@ class vmmNetwork(vmmLibvirtObject):
 
     def get_ipv4_network(self):
         xml = self.get_xml()
-        addrStr = util.get_xml_path(xml, "/network/ip/@address")
-        netmaskStr = util.get_xml_path(xml, "/network/ip/@netmask")
+        addrStr = util.xpath(xml, "/network/ip/@address")
+        netmaskStr = util.xpath(xml, "/network/ip/@netmask")
 
         netmask = IP(netmaskStr)
         gateway = IP(addrStr)
@@ -113,14 +108,14 @@ class vmmNetwork(vmmLibvirtObject):
 
     def get_ipv4_forward(self):
         xml = self.get_xml()
-        fw = util.get_xml_path(xml, "/network/forward/@mode")
-        forwardDev = util.get_xml_path(xml, "/network/forward/@dev")
+        fw = util.xpath(xml, "/network/forward/@mode")
+        forwardDev = util.xpath(xml, "/network/forward/@dev")
         return [fw, forwardDev]
 
     def get_ipv4_dhcp_range(self):
         xml = self.get_xml()
-        dhcpstart = util.get_xml_path(xml, "/network/ip/dhcp/range[1]/@start")
-        dhcpend = util.get_xml_path(xml, "/network/ip/dhcp/range[1]/@end")
+        dhcpstart = util.xpath(xml, "/network/ip/dhcp/range[1]/@start")
+        dhcpend = util.xpath(xml, "/network/ip/dhcp/range[1]/@end")
         if not dhcpstart or not dhcpend:
             return None
 
@@ -135,6 +130,6 @@ class vmmNetwork(vmmLibvirtObject):
         forward = self.get_ipv4_forward()[0]
         if forward and forward != "nat":
             return True
-        return bool(util.get_xml_path(xml, "/network/ip/dhcp/bootp/@file"))
+        return bool(util.xpath(xml, "/network/ip/dhcp/bootp/@file"))
 
 vmmLibvirtObject.type_register(vmmNetwork)
